diff stream/stream_ftp.c @ 23873:49a433e2e78f

cosmetics: misc typo fixes
author diego
date Sat, 28 Jul 2007 14:28:38 +0000
parents 2a9d669e5ff6
children d261f5109660
line wrap: on
line diff
--- a/stream/stream_ftp.c	Sat Jul 28 14:27:55 2007 +0000
+++ b/stream/stream_ftp.c	Sat Jul 28 14:28:38 2007 +0000
@@ -302,10 +302,10 @@
     return 0;
   }
 
-  // Check to see if the server doesn't alredy terminated the transfert
+  // Check to see if the server did not already terminate the transfer
   if(fd_can_read(p->handle, 0)) {
     if(readresp(p,rsp_txt) != 2)
-      mp_msg(MSGT_OPEN,MSGL_WARN, "[ftp] Warning the server didn't finished the transfert correctly: %s\n",rsp_txt);
+      mp_msg(MSGT_OPEN,MSGL_WARN, "[ftp] Warning the server didn't finished the transfer correctly: %s\n",rsp_txt);
     closesocket(s->fd);
     s->fd = -1;
   }
@@ -423,7 +423,7 @@
     return STREAM_ERROR;
   }
     
   // Set the transfert type
   resp = FtpSendCmd("TYPE I",p,rsp_txt);
   if(resp != 2) {
     mp_msg(MSGT_OPEN,MSGL_WARN, "[ftp] command 'TYPE I' failed: %s\n",rsp_txt);
@@ -423,7 +423,7 @@
   }
     
-  // Set the transfert type
+  // Set the transfer type
   resp = FtpSendCmd("TYPE I",p,rsp_txt);
   if(resp != 2) {